This is an automated email from the ASF dual-hosted git repository.

epugh pushed a commit to branch main
in repository https://gitbox.apache.org/repos/asf/solr.git


The following commit(s) were added to refs/heads/main by this push:
     new adf9e6d  SOLR-15327: Fix typos spread in code base (#65)
adf9e6d is described below

commit adf9e6d39cc55d87c0ae09748891bf0f6009a2b5
Author: Edward Ribeiro <[email protected]>
AuthorDate: Fri Apr 9 10:16:57 2021 -0300

    SOLR-15327: Fix typos spread in code base (#65)
    
    * SOLR-15327: Fix typos in the code base
---
 solr/CHANGES.txt                                   | 10 ++++----
 .../handler/component/RealTimeGetComponent.java    | 28 +++++++++++-----------
 .../solr/handler/component/SearchHandler.java      |  2 +-
 .../apache/solr/handler/component/StatsField.java  |  8 +++----
 .../src/java/org/apache/solr/schema/FieldType.java |  8 +++----
 .../src/java/org/apache/solr/schema/TextField.java |  2 +-
 ...-psuedo-fields.xml => schema-pseudo-fields.xml} |  2 +-
 .../solr/collection1/conf/schema-trie.xml          |  4 ++--
 .../test-files/solr/collection1/conf/schema11.xml  |  4 ++--
 .../test-files/solr/collection1/conf/schema12.xml  |  2 +-
 .../solr/collection1/conf/schema_latest.xml        |  2 +-
 .../solr/cloud/TestCloudPseudoReturnFields.java    |  8 +++----
 .../apache/solr/cloud/TestRandomFlRTGCloud.java    |  2 +-
 .../solr/search/TestExtendedDismaxParser.java      |  2 +-
 .../apache/solr/search/TestPseudoReturnFields.java |  6 ++---
 .../search/facet/TestCloudJSONFacetJoinDomain.java |  2 +-
 .../search/facet/TestCloudJSONFacetSKGEquiv.java   |  2 +-
 .../conf/managed-schema                            |  2 +-
 .../src/documents-fields-and-schema-design.adoc    |  2 +-
 .../src/indexing-nested-documents.adoc             |  6 ++---
 .../src/searching-nested-documents.adoc            |  2 +-
 .../src/transforming-result-documents.adoc         |  4 ++--
 .../src/updating-parts-of-documents.adoc           |  6 ++---
 solr/solr-ref-guide/tools/BuildNavDataFiles.java   |  2 +-
 .../solr-ref-guide/tools/CheckLinksAndAnchors.java | 22 ++++++++---------
 .../solr/client/solrj/io/stream/RandomStream.java  |  2 +-
 .../IndexingNestedDocuments.java                   |  2 +-
 .../apache/solr/client/solrj/SolrExampleTests.java | 26 ++++++++++----------
 .../java/org/apache/solr/util/SSLTestConfig.java   | 10 ++++----
 29 files changed, 91 insertions(+), 89 deletions(-)

diff --git a/solr/CHANGES.txt b/solr/CHANGES.txt
index 2576b7e..2791f1f 100644
--- a/solr/CHANGES.txt
+++ b/solr/CHANGES.txt
@@ -48,6 +48,8 @@ Improvements
 
 * SOLR-14387: SolrClient.getById() will escape comma separater within ids 
(Markus Schuch via Mike Drob)
 
+* SOLR-15327: Fix typos in the code base (Edward Ribeiro via Eric Pugh)
+
 * SOLR-10814: Add short-name feature to RuleBasedAuthz plugin (Mike Drob, 
Hrishikesh Gadre)
 
 * SOLR-7683 Introduce support to identify Solr internal request types (Atri 
Sharma, Hrishikesh Gadre)
@@ -7446,7 +7448,7 @@ Other Changes
 
 * SOLR-8787: TestAuthenticationFramework should not extend 
TestMiniSolrCloudCluster. (Trey Cahill via shalin)
 
-* SOLR-9180: More comprehensive tests of psuedo-fields for RTG and SolrCloud 
requests (hossman)
+* SOLR-9180: More comprehensive tests of pseudo-fields for RTG and SolrCloud 
requests (hossman)
 
 * SOLR-7930: Comment out trappy references to example docs in elevate.xml 
files (Erick Erickson)
 
@@ -7842,8 +7844,8 @@ Other Changes
 * SOLR-5776,SOLR-9068,SOLR-8970:
   - Refactor SSLConfig so that SSLTestConfig can provide SSLContexts using a 
NullSecureRandom
     to prevent SSL tests from blocking on entropy starved machines.
-  - SSLTestConfig: Alternate (psuedo random) NullSecureRandom for 
Constants.SUN_OS.
-  - SSLTestConfig: Replace NullSecureRandom w/ NotSecurePsuedoRandom.
+  - SSLTestConfig: Alternate (pseudo random) NullSecureRandom for 
Constants.SUN_OS.
+  - SSLTestConfig: Replace NullSecureRandom w/ NotSecurePseudoRandom.
   - Change SSLTestConfig to use a keystore file that is included as a resource 
in the
     test-framework jar so users subclassing SolrTestCaseJ4 don't need to 
preserve magic paths.
   (hossman)
@@ -16553,7 +16555,7 @@ Bug Fixes
   empty index. (Adrien Grand via Mark Miller)
 
 * SOLR-2352: Fixed TermVectorComponent so that it will not fail if the fl
-  param contains globs or psuedo-fields (hossman)
+  param contains globs or pseudo-fields (hossman)
 
 * SOLR-3541: add missing solrj dependencies to binary packages.
   (Thijs Vonk via siren)
diff --git 
a/solr/core/src/java/org/apache/solr/handler/component/RealTimeGetComponent.java
 
b/solr/core/src/java/org/apache/solr/handler/component/RealTimeGetComponent.java
index c5751d3..e24b02c 100644
--- 
a/solr/core/src/java/org/apache/solr/handler/component/RealTimeGetComponent.java
+++ 
b/solr/core/src/java/org/apache/solr/handler/component/RealTimeGetComponent.java
@@ -191,7 +191,7 @@ public class RealTimeGetComponent extends SearchComponent
       return;
     }
 
-    final IdsRequsted reqIds = IdsRequsted.parseParams(req);
+    final IdsRequested reqIds = IdsRequested.parseParams(req);
     
     if (reqIds.allIds.isEmpty()) {
       return;
@@ -967,7 +967,7 @@ public class RealTimeGetComponent extends SearchComponent
 
   public int createSubRequests(ResponseBuilder rb) throws IOException {
     
-    final IdsRequsted reqIds = IdsRequsted.parseParams(rb.req);
+    final IdsRequested reqIds = IdsRequested.parseParams(rb.req);
     if (reqIds.allIds.isEmpty()) {
       return ResponseBuilder.STAGE_DONE;
     }
@@ -1100,7 +1100,7 @@ public class RealTimeGetComponent extends SearchComponent
     assert null != docList;
     
     final SolrQueryResponse rsp = rb.rsp;
-    final IdsRequsted reqIds = IdsRequsted.parseParams(rb.req);
+    final IdsRequested reqIds = IdsRequested.parseParams(rb.req);
     
     if (reqIds.useSingleDocResponse) {
       assert docList.size() <= 1;
@@ -1345,18 +1345,18 @@ public class RealTimeGetComponent extends 
SearchComponent
 
   /** 
    * Simple struct for tracking what ids were requested and what response 
format is expected 
-   * acording to the request params
+   * according to the request params
    */
-  private final static class IdsRequsted {
+  private final static class IdsRequested {
     /** An List (which may be empty but will never be null) of the uniqueKeys 
requested. */
     public final List<String> allIds;
     /** 
      * true if the params provided by the user indicate that a single doc 
response structure 
      * should be used.  
-     * Value is meaninless if <code>ids</code> is empty.
+     * Value is meaningless if <code>ids</code> is empty.
      */
     public final boolean useSingleDocResponse;
-    private IdsRequsted(List<String> allIds, boolean useSingleDocResponse) {
+    private IdsRequested(List<String> allIds, boolean useSingleDocResponse) {
       assert null != allIds;
       this.allIds = allIds;
       this.useSingleDocResponse = useSingleDocResponse;
@@ -1364,21 +1364,21 @@ public class RealTimeGetComponent extends 
SearchComponent
     
     /**
      * Parsers the <code>id</code> and <code>ids</code> params attached to the 
specified request object, 
-     * and returns an <code>IdsRequsted</code> struct to use for this request.
-     * The <code>IdsRequsted</code> is cached in the {@link 
SolrQueryRequest#getContext} so subsequent 
+     * and returns an <code>IdsRequested</code> struct to use for this request.
+     * The <code>IdsRequested</code> is cached in the {@link 
SolrQueryRequest#getContext} so subsequent
      * method calls on the same request will not re-parse the params.
      */
-    public static IdsRequsted parseParams(SolrQueryRequest req) {
-      final String contextKey = IdsRequsted.class.toString() + 
"_PARSED_ID_PARAMS";
+    public static IdsRequested parseParams(SolrQueryRequest req) {
+      final String contextKey = IdsRequested.class.toString() + 
"_PARSED_ID_PARAMS";
       if (req.getContext().containsKey(contextKey)) {
-        return (IdsRequsted)req.getContext().get(contextKey);
+        return (IdsRequested)req.getContext().get(contextKey);
       }
       final SolrParams params = req.getParams();
       final String id[] = params.getParams(ID);
       final String ids[] = params.getParams("ids");
       
       if (id == null && ids == null) {
-        IdsRequsted result = new IdsRequsted(Collections.<String>emptyList(), 
true);
+        IdsRequested result = new 
IdsRequested(Collections.<String>emptyList(), true);
         req.getContext().put(contextKey, result);
         return result;
       }
@@ -1396,7 +1396,7 @@ public class RealTimeGetComponent extends SearchComponent
       }
       // if the client specified a single id=foo, then use "doc":{
       // otherwise use a standard doclist
-      IdsRequsted result = new IdsRequsted(allIds, (ids == null && 
allIds.size() <= 1));
+      IdsRequested result = new IdsRequested(allIds, (ids == null && 
allIds.size() <= 1));
       req.getContext().put(contextKey, result);
       return result;
     }
diff --git 
a/solr/core/src/java/org/apache/solr/handler/component/SearchHandler.java 
b/solr/core/src/java/org/apache/solr/handler/component/SearchHandler.java
index affbfd6..ea4f6f8 100644
--- a/solr/core/src/java/org/apache/solr/handler/component/SearchHandler.java
+++ b/solr/core/src/java/org/apache/solr/handler/component/SearchHandler.java
@@ -344,7 +344,7 @@ public class SearchHandler extends RequestHandlerBase 
implements SolrCoreAware,
       subt.stop();
     }
 
-    { // Once all of our components have been prepared, check if this requset 
involves a SortSpec.
+    { // Once all of our components have been prepared, check if this request 
involves a SortSpec.
       // If it does, and if our request includes a cursorMark param, then 
parse & init the CursorMark state
       // (This must happen after the prepare() of all components, because any 
component may have modified the SortSpec)
       final SortSpec spec = rb.getSortSpec();
diff --git 
a/solr/core/src/java/org/apache/solr/handler/component/StatsField.java 
b/solr/core/src/java/org/apache/solr/handler/component/StatsField.java
index 0483bb0..b90cf1f 100644
--- a/solr/core/src/java/org/apache/solr/handler/component/StatsField.java
+++ b/solr/core/src/java/org/apache/solr/handler/component/StatsField.java
@@ -184,7 +184,7 @@ public class StatsField {
    * @see Stat#countDistinct
    * @see Stat#distinctValues
    */
-  private static final EnumSet<Stat> CALCDISTINCT_PSUEDO_STAT = 
EnumSet.of(Stat.countDistinct, Stat.distinctValues);
+  private static final EnumSet<Stat> CALCDISTINCT_PSEUDO_STAT = 
EnumSet.of(Stat.countDistinct, Stat.distinctValues);
 
   /**
    * The set of stats computed by default when no localparams are used to 
specify explicit stats 
@@ -542,15 +542,15 @@ public class StatsField {
 
     // if no individual stat setting use the default set
     if ( ! ( statSpecifiedByLocalParam
-             // calcdistinct (as a local param) is a psuedo-stat, prevents 
default set
+             // calcdistinct (as a local param) is a pseudo-stat, prevents 
default set
              || localParams.getBool("calcdistinct", false) ) ) {
       statsInResponse.addAll(DEFAULT_STATS);
     }
 
-    // calcDistinct is a psuedo-stat with optional top level param default 
behavior
+    // calcDistinct is a pseudo-stat with optional top level param default 
behavior
     // if not overridden by the specific individual stats
     if (localParams.getBool("calcdistinct", topLevelCalcDistinct)) {
-      for (Stat stat : CALCDISTINCT_PSUEDO_STAT) {
+      for (Stat stat : CALCDISTINCT_PSEUDO_STAT) {
         // assume true, but don't include if specific stat overrides
         if (localParams.getBool(stat.name(), true)) {
           statsInResponse.add(stat);
diff --git a/solr/core/src/java/org/apache/solr/schema/FieldType.java 
b/solr/core/src/java/org/apache/solr/schema/FieldType.java
index c29eecc..7f53479 100644
--- a/solr/core/src/java/org/apache/solr/schema/FieldType.java
+++ b/solr/core/src/java/org/apache/solr/schema/FieldType.java
@@ -861,7 +861,7 @@ public abstract class FieldType extends FieldProperties {
    * different semantics.
    * <p>
    * By default range queries with '*'s or nulls on either side are treated as 
existence queries and are created with {@link #getExistenceQuery}.
-   * If unbounded range queries should not be treated as existence queries for 
a certain fieldType, then {@link #treatUnboundedRangeAsExistence} should be 
overriden.
+   * If unbounded range queries should not be treated as existence queries for 
a certain fieldType, then {@link #treatUnboundedRangeAsExistence} should be 
overridden.
    * <p>
    * Sub-classes should override the {@link #getSpecializedRangeQuery} method 
to provide their own range query implementation.
    *
@@ -933,8 +933,8 @@ public abstract class FieldType extends FieldProperties {
    * Returns a Query instance for doing existence searches for a field.
    * If the field does not have docValues or norms, this method will call 
{@link #getSpecializedExistenceQuery}, which defaults to an unbounded 
rangeQuery.
    * <p>
-   * This method should only be overriden whenever a fieldType does not 
support {@link org.apache.lucene.search.DocValuesFieldExistsQuery} or {@link 
org.apache.lucene.search.NormsFieldExistsQuery}.
-   * If a fieldType does not support an unbounded rangeQuery as an 
existenceQuery (such as <code>double</code> or <code>float</code> fields), 
{@link #getSpecializedExistenceQuery} should be overriden.
+   * This method should only be overridden whenever a fieldType does not 
support {@link org.apache.lucene.search.DocValuesFieldExistsQuery} or {@link 
org.apache.lucene.search.NormsFieldExistsQuery}.
+   * If a fieldType does not support an unbounded rangeQuery as an 
existenceQuery (such as <code>double</code> or <code>float</code> fields), 
{@link #getSpecializedExistenceQuery} should be overridden.
    *
    * @param parser The {@link org.apache.solr.search.QParser} calling the 
method
    * @param field The {@link org.apache.solr.schema.SchemaField} of the field 
to search
@@ -954,7 +954,7 @@ public abstract class FieldType extends FieldProperties {
   /**
    * Returns a Query instance for doing existence searches for a field without 
certain options, such as docValues or norms.
    * <p>
-   * This method can be overriden to implement specialized existence logic for 
fieldTypes.
+   * This method can be overridden to implement specialized existence logic 
for fieldTypes.
    * The default query returned is an unbounded range query.
    *
    * @param parser The {@link org.apache.solr.search.QParser} calling the 
method
diff --git a/solr/core/src/java/org/apache/solr/schema/TextField.java 
b/solr/core/src/java/org/apache/solr/schema/TextField.java
index 2e44e67..d79823b 100644
--- a/solr/core/src/java/org/apache/solr/schema/TextField.java
+++ b/solr/core/src/java/org/apache/solr/schema/TextField.java
@@ -122,7 +122,7 @@ public class TextField extends FieldType {
                                  // historical behavior based on how the early 
versions of the FieldCache
                                  // would deal with multiple indexed terms in 
a singled valued field...
                                  //
-                                 // Always use the 'min' value from the 
(Uninverted) "psuedo doc values"
+                                 // Always use the 'min' value from the 
(Uninverted) "pseudo doc values"
                                  SortedSetSelector.Type.MIN,
                                  reverse, SortField.STRING_FIRST, 
SortField.STRING_LAST);
   }
diff --git 
a/solr/core/src/test-files/solr/collection1/conf/schema-psuedo-fields.xml 
b/solr/core/src/test-files/solr/collection1/conf/schema-pseudo-fields.xml
similarity index 98%
rename from 
solr/core/src/test-files/solr/collection1/conf/schema-psuedo-fields.xml
rename to 
solr/core/src/test-files/solr/collection1/conf/schema-pseudo-fields.xml
index b4e2ecd..17cbece 100644
--- a/solr/core/src/test-files/solr/collection1/conf/schema-psuedo-fields.xml
+++ b/solr/core/src/test-files/solr/collection1/conf/schema-pseudo-fields.xml
@@ -25,7 +25,7 @@
 
   <dynamicField name="*_srpt" type="location_rpt" indexed="true" 
stored="true"/>  
   <dynamicField name="*_i" type="int" indexed="true" stored="true"/>
-  <!-- for testing if score psuedofield is erroneously treated as multivalued
+  <!-- for testing if score pseudofield is erroneously treated as multivalued
        when a matching dynamic field exists 
   -->
   <dynamicField name="*core" type="ignored" multiValued="true"/>
diff --git a/solr/core/src/test-files/solr/collection1/conf/schema-trie.xml 
b/solr/core/src/test-files/solr/collection1/conf/schema-trie.xml
index cc0ff03..8669d64 100644
--- a/solr/core/src/test-files/solr/collection1/conf/schema-trie.xml
+++ b/solr/core/src/test-files/solr/collection1/conf/schema-trie.xml
@@ -114,12 +114,12 @@
 
   <!-- The "RandomSortField" is not used to store or search any
        data.  You can declare fields of this type it in your schema
-       to generate psuedo-random orderings of your docs for sorting
+       to generate pseudo-random orderings of your docs for sorting
        purposes.  The ordering is generated based on the field name
        and the version of the index, As long as the index version
        remains unchanged, and the same field name is reused,
        the ordering of the docs will be consistent.
-       If you want differend psuedo-random orderings of documents,
+       If you want different pseudo-random orderings of documents,
        for the same version of the index, use a dynamicField and
        change the name
    -->
diff --git a/solr/core/src/test-files/solr/collection1/conf/schema11.xml 
b/solr/core/src/test-files/solr/collection1/conf/schema11.xml
index 0dff57f..d791793 100644
--- a/solr/core/src/test-files/solr/collection1/conf/schema11.xml
+++ b/solr/core/src/test-files/solr/collection1/conf/schema11.xml
@@ -110,12 +110,12 @@
 
     <!-- The "RandomSortField" is not used to store or search any
          data.  You can declare fields of this type it in your schema
-         to generate psuedo-random orderings of your docs for sorting 
+         to generate pseudo-random orderings of your docs for sorting
          purposes.  The ordering is generated based on the field name 
          and the version of the index, As long as the index version
          remains unchanged, and the same field name is reused,
          the ordering of the docs will be consistent.  
-         If you want differend psuedo-random orderings of documents,
+         If you want different pseudo-random orderings of documents,
          for the same version of the index, use a dynamicField and
          change the name
      -->
diff --git a/solr/core/src/test-files/solr/collection1/conf/schema12.xml 
b/solr/core/src/test-files/solr/collection1/conf/schema12.xml
index d4cb89e..33468f9 100644
--- a/solr/core/src/test-files/solr/collection1/conf/schema12.xml
+++ b/solr/core/src/test-files/solr/collection1/conf/schema12.xml
@@ -792,7 +792,7 @@
   <dynamicField name="bar_copydest_*" type="ignored" multiValued="true"/>
   <dynamicField name="*_es" type="text" indexed="true" stored="true"/>
 
-  <!-- for testing if score psuedofield is erroneously treated as multivalued
+  <!-- for testing if score pseudofield is erroneously treated as multivalued
        when a matching dynamic field exists 
   -->
   <dynamicField name="*core" type="ignored" multiValued="true"/>
diff --git a/solr/core/src/test-files/solr/collection1/conf/schema_latest.xml 
b/solr/core/src/test-files/solr/collection1/conf/schema_latest.xml
index 18cfedc..693847b 100644
--- a/solr/core/src/test-files/solr/collection1/conf/schema_latest.xml
+++ b/solr/core/src/test-files/solr/collection1/conf/schema_latest.xml
@@ -456,7 +456,7 @@
        name and the version of the index. As long as the index version
        remains unchanged, and the same field name is reused,
        the ordering of the docs will be consistent.  
-       If you want different psuedo-random orderings of documents,
+       If you want different pseudo-random orderings of documents,
        for the same version of the index, use a dynamicField and
        change the field name in the request.
    -->
diff --git a/solr/core/src/test/org/apache/solr/cloud/TestRandomFlRTGCloud.java 
b/solr/core/src/test/org/apache/solr/cloud/TestRandomFlRTGCloud.java
index b20f3df..c119d4f 100644
--- a/solr/core/src/test/org/apache/solr/cloud/TestRandomFlRTGCloud.java
+++ b/solr/core/src/test/org/apache/solr/cloud/TestRandomFlRTGCloud.java
@@ -143,7 +143,7 @@ public class TestRandomFlRTGCloud extends SolrCloudTestCase 
{
 
     CollectionAdminRequest.createCollection(COLLECTION_NAME, configName, 
numShards, repFactor)
         .withProperty("config", "solrconfig-tlog.xml")
-        .withProperty("schema", "schema-psuedo-fields.xml")
+        .withProperty("schema", "schema-pseudo-fields.xml")
         .process(CLOUD_CLIENT);
 
     cluster.waitForActiveCollection(COLLECTION_NAME, numShards, repFactor * 
numShards); 
diff --git 
a/solr/core/src/test/org/apache/solr/search/TestExtendedDismaxParser.java 
b/solr/core/src/test/org/apache/solr/search/TestExtendedDismaxParser.java
index f94f421..107841e 100644
--- a/solr/core/src/test/org/apache/solr/search/TestExtendedDismaxParser.java
+++ b/solr/core/src/test/org/apache/solr/search/TestExtendedDismaxParser.java
@@ -419,7 +419,7 @@ public class TestExtendedDismaxParser extends 
SolrTestCaseJ4 {
     assertQ(req("defType","edismax", "mm","0", "q","movies_t:Terminator 100", 
"qf","movies_t foo_i"),
             twor);
     
-    // special psuedo-fields like _query_ and _val_
+    // special pseudo-fields like _query_ and _val_
 
     // _query_ should be excluded by default
     assertQ(req("defType", "edismax", 
diff --git 
a/solr/core/src/test/org/apache/solr/search/facet/TestCloudJSONFacetJoinDomain.java
 
b/solr/core/src/test/org/apache/solr/search/facet/TestCloudJSONFacetJoinDomain.java
index c1dc549..4460642 100644
--- 
a/solr/core/src/test/org/apache/solr/search/facet/TestCloudJSONFacetJoinDomain.java
+++ 
b/solr/core/src/test/org/apache/solr/search/facet/TestCloudJSONFacetJoinDomain.java
@@ -171,7 +171,7 @@ public class TestCloudJSONFacetJoinDomain extends 
SolrCloudTestCase {
 
   /**
    * Given a (random) field number, returns a random (integer based) value for 
that field.
-   * NOTE: The number of unique values in each field is constant acording to 
{@link #UNIQUE_FIELD_VALS}
+   * NOTE: The number of unique values in each field is constant according to 
{@link #UNIQUE_FIELD_VALS}
    * but the precise <em>range</em> of values will vary for each unique field 
number, such that cross field joins 
    * will match fewer documents based on how far apart the field numbers are.
    *
diff --git 
a/solr/core/src/test/org/apache/solr/search/facet/TestCloudJSONFacetSKGEquiv.java
 
b/solr/core/src/test/org/apache/solr/search/facet/TestCloudJSONFacetSKGEquiv.java
index e3d8085..293463e 100644
--- 
a/solr/core/src/test/org/apache/solr/search/facet/TestCloudJSONFacetSKGEquiv.java
+++ 
b/solr/core/src/test/org/apache/solr/search/facet/TestCloudJSONFacetSKGEquiv.java
@@ -214,7 +214,7 @@ public class TestCloudJSONFacetSKGEquiv extends 
SolrCloudTestCase {
 
   /**
    * Given a (random) field number, returns a random (integer based) value for 
that field.
-   * NOTE: The number of unique values in each field is constant acording to 
{@link #UNIQUE_FIELD_VALS}
+   * NOTE: The number of unique values in each field is constant according to 
{@link #UNIQUE_FIELD_VALS}
    * but the precise <em>range</em> of values will vary for each unique field 
number, such that cross field joins 
    * will match fewer documents based on how far apart the field numbers are.
    *
diff --git 
a/solr/server/solr/configsets/sample_techproducts_configs/conf/managed-schema 
b/solr/server/solr/configsets/sample_techproducts_configs/conf/managed-schema
index 9ddbf38..81de184 100644
--- 
a/solr/server/solr/configsets/sample_techproducts_configs/conf/managed-schema
+++ 
b/solr/server/solr/configsets/sample_techproducts_configs/conf/managed-schema
@@ -353,7 +353,7 @@
          name and the version of the index. As long as the index version
          remains unchanged, and the same field name is reused,
          the ordering of the docs will be consistent.  
-         If you want different psuedo-random orderings of documents,
+         If you want different pseudo-random orderings of documents,
          for the same version of the index, use a dynamicField and
          change the field name in the request.
      -->
diff --git a/solr/solr-ref-guide/src/documents-fields-and-schema-design.adoc 
b/solr/solr-ref-guide/src/documents-fields-and-schema-design.adoc
index 125a024..04c4ae5 100644
--- a/solr/solr-ref-guide/src/documents-fields-and-schema-design.adoc
+++ b/solr/solr-ref-guide/src/documents-fields-and-schema-design.adoc
@@ -41,4 +41,4 @@ This section includes the following topics:
 
 <<schemaless-mode.adoc#,Schemaless Mode>>: Automatically add previously 
unknown schema fields using value-based field type guessing.
 
-<<luke-request-handler.adoc#,Luke Requst Handler>>: The request handler which 
provides access to information about fields in the index. This request handler 
powers the <<schema-browser-screen.adoc#,Schema Browser>> page of Solr's Admin 
UI.
+<<luke-request-handler.adoc#,Luke Request Handler>>: The request handler which 
provides access to information about fields in the index. This request handler 
powers the <<schema-browser-screen.adoc#,Schema Browser>> page of Solr's Admin 
UI.
diff --git a/solr/solr-ref-guide/src/indexing-nested-documents.adoc 
b/solr/solr-ref-guide/src/indexing-nested-documents.adoc
index 084dc01..611f881 100644
--- a/solr/solr-ref-guide/src/indexing-nested-documents.adoc
+++ b/solr/solr-ref-guide/src/indexing-nested-documents.adoc
@@ -50,10 +50,10 @@ generate such IDs; you can let Solr populate them 
automatically.  It will concat
 parent with a separator and path information that should be unique.  Try it 
out for yourself!
 
 [#example-indexing-syntax]
-== Example Indexing Syntax: Psuedo-Fields
+== Example Indexing Syntax: Pseudo-Fields
 
 This example shows what it looks like to index two root "product" documents, 
each containing two
-different types of child documents specified in "psuedo-fields": "skus" and 
"manuals".  Two of the "sku" type documents have their own nested child 
"manuals" documents...
+different types of child documents specified in "pseudo-fields": "skus" and 
"manuals".  Two of the "sku" type documents have their own nested child 
"manuals" documents...
 
 [NOTE]
 ====
@@ -424,7 +424,7 @@ This simplified approach was common in older versions of 
Solr, and can still be
 This approach should *NOT* be used when schemas include a `\_nest_path_` 
field, as the existence of that field triggers assumptions and changes in 
behavior in various query time functionality, such as the 
<<searching-nested-documents.adoc#child-doc-transformer,[child]>>, that will 
not work when nested documents do not have any intrinsic "nested path" 
information.
 
 The results of indexing anonymous nested children with a "Root-Only" schema 
are similar to what
-happens if you attempt to index "psuedo field" nested documents using a 
"Root-Only" schema.
+happens if you attempt to index "pseudo field" nested documents using a 
"Root-Only" schema.
 Notably: since there is no nested path information for the
 <<searching-nested-documents.adoc#child-doc-transformer,[child]>> transformer 
to use to reconstruct the structure of a nest
 of documents, it returns all matching children as a flat list, similar in 
structure to how they were originally indexed:
diff --git a/solr/solr-ref-guide/src/searching-nested-documents.adoc 
b/solr/solr-ref-guide/src/searching-nested-documents.adoc
index 16b4da7..9d690c1 100644
--- a/solr/solr-ref-guide/src/searching-nested-documents.adoc
+++ b/solr/solr-ref-guide/src/searching-nested-documents.adoc
@@ -53,7 +53,7 @@ $ curl 
'http://localhost:8983/solr/gettingstarted/select?omitHeader=true&q=descr
   }}
 ----
 
-The same query with the addition of the `[child]` transformer is shown below.  
Note that the `numFound` has not changed, we are still matching the same set of 
documents, but when returning those documents the nested children are also 
returned as psuedo-fields.
+The same query with the addition of the `[child]` transformer is shown below.  
Note that the `numFound` has not changed, we are still matching the same set of 
documents, but when returning those documents the nested children are also 
returned as pseudo-fields.
 
 [source,curl]
 ----
diff --git a/solr/solr-ref-guide/src/transforming-result-documents.adoc 
b/solr/solr-ref-guide/src/transforming-result-documents.adoc
index f2859af..236864f 100644
--- a/solr/solr-ref-guide/src/transforming-result-documents.adoc
+++ b/solr/solr-ref-guide/src/transforming-result-documents.adoc
@@ -135,7 +135,7 @@ Note that this transformer can be used even when the query 
used to match the res
 q=book_title:Solr&fl=id,[child childFilter=doc_type:chapter limit=100]
 ----
 
-If the documents involved include a `\_nest_path_` field, then it is used to 
re-create the hierarchical structure of the descendent documents using the 
original psuedo-field names the documents were indexed with, otherwise the 
descendent documents are returned as a flat list of 
<<indexing-nested-documents#indexing-anonymous-children,anonymous children>>.
+If the documents involved include a `\_nest_path_` field, then it is used to 
re-create the hierarchical structure of the descendent documents using the 
original pseudo-field names the documents were indexed with, otherwise the 
descendent documents are returned as a flat list of 
<<indexing-nested-documents#indexing-anonymous-children,anonymous children>>.
 
 `childFilter`::
 A query to filter which child documents should be included. This can be 
particularly useful when you have multiple levels of hierarchical documents. 
The default is all children.
@@ -163,7 +163,7 @@ When a `\_nest_path_` field is defined, the `childFilter` 
option supports an exp
 
 *This syntax is triggered by including a `/` seperated path structure prior to 
a query that includes a `:` character.*
 
-When the "path" begins with a `/` character, it restricts matches to documents 
that have that exist "path" of nested psuedo-field documents, starting at the 
Root document of the block (even if the document being transformed is not a 
Root level document)
+When the "path" begins with a `/` character, it restricts matches to documents 
that have that exist "path" of nested pseudo-field documents, starting at the 
Root document of the block (even if the document being transformed is not a 
Root level document)
 
 Some Examples:
 
diff --git a/solr/solr-ref-guide/src/updating-parts-of-documents.adoc 
b/solr/solr-ref-guide/src/updating-parts-of-documents.adoc
index 830c632..470156b 100644
--- a/solr/solr-ref-guide/src/updating-parts-of-documents.adoc
+++ b/solr/solr-ref-guide/src/updating-parts-of-documents.adoc
@@ -156,7 +156,7 @@ curl -X POST 
'http://localhost:8983/solr/gettingstarted/update?commit=true' -H '
 
 ==== Replacing All Child Documents
 
-As with normal (multiValued) fields, the `set` keyword can be used to replace 
all child documents in a psuedo-field:
+As with normal (multiValued) fields, the `set` keyword can be used to replace 
all child documents in a pseudo-field:
 
 [source,bash]
 ----
@@ -178,7 +178,7 @@ curl -X POST 
'http://localhost:8983/solr/gettingstarted/update?commit=true' -H '
 
 ==== Adding a Child Document
 
-As with normal (multiValued) fields, the `add` keyword can be used to add 
additional child documents to a psuedo-field:
+As with normal (multiValued) fields, the `add` keyword can be used to add 
additional child documents to a pseudo-field:
 
 [source,bash]
 ----
@@ -196,7 +196,7 @@ curl -X POST 
'http://localhost:8983/solr/gettingstarted/update?commit=true' -H '
 
 ==== Removing a Child Document
 
-As with normal (multiValued) fields, the `remove` keyword can be used to 
remove a child document (by `id`) from it's psuedo-field:
+As with normal (multiValued) fields, the `remove` keyword can be used to 
remove a child document (by `id`) from it's pseudo-field:
 
 [source,bash]
 ----
diff --git a/solr/solr-ref-guide/tools/BuildNavDataFiles.java 
b/solr/solr-ref-guide/tools/BuildNavDataFiles.java
index 548573f..5b87bb8 100644
--- a/solr/solr-ref-guide/tools/BuildNavDataFiles.java
+++ b/solr/solr-ref-guide/tools/BuildNavDataFiles.java
@@ -66,7 +66,7 @@ public class BuildNavDataFiles {
     if (null == mainPage) {
       throw new RuntimeException("no main-page found with shortname: " + 
mainPageShortname);
     }
-    // NOTE: mainPage claims to be its own parent to prevent anyone decendent 
from introducing a loop
+    // NOTE: mainPage claims to be its own parent to prevent anyone descendant 
from introducing a loop
     mainPage.buildPageTreeRecursive(mainPage, allPages);
 
     { // validate that there are no orphan pages
diff --git 
a/solr/test-framework/src/java/org/apache/solr/util/SSLTestConfig.java 
b/solr/test-framework/src/java/org/apache/solr/util/SSLTestConfig.java
index 571bec1..5a5036d 100644
--- a/solr/test-framework/src/java/org/apache/solr/util/SSLTestConfig.java
+++ b/solr/test-framework/src/java/org/apache/solr/util/SSLTestConfig.java
@@ -164,7 +164,7 @@ public class SSLTestConfig {
     assert isSSLMode();
     
     SSLContextBuilder builder = SSLContexts.custom();
-    builder.setSecureRandom(NotSecurePsuedoRandom.INSTANCE);
+    builder.setSecureRandom(NotSecurePseudoRandom.INSTANCE);
     
     // NOTE: KeyStore & TrustStore are swapped because they are from 
configured from server perspective...
     // we are a client - our keystore contains the keys the server trusts, and 
vice versa
@@ -216,7 +216,7 @@ public class SSLTestConfig {
         SslContextFactory.Server factory = new SslContextFactory.Server();
         try {
           SSLContextBuilder builder = SSLContexts.custom();
-          builder.setSecureRandom(NotSecurePsuedoRandom.INSTANCE);
+          builder.setSecureRandom(NotSecurePseudoRandom.INSTANCE);
 
           builder.loadKeyMaterial(buildKeyStore(keyStore, TEST_PASSWORD), 
TEST_PASSWORD.toCharArray());
 
@@ -296,8 +296,8 @@ public class SSLTestConfig {
    * SecureRandom instances due to too many instances / not enough random 
entropy.  
    * Tests do not need secure SSL.
    */
-  private static class NotSecurePsuedoRandom extends SecureRandom {
-    public static final SecureRandom INSTANCE = new NotSecurePsuedoRandom();
+  private static class NotSecurePseudoRandom extends SecureRandom {
+    public static final SecureRandom INSTANCE = new NotSecurePseudoRandom();
     private static final Random RAND = new Random(42);
     
     /** 
@@ -323,7 +323,7 @@ public class SSLTestConfig {
       public void engineSetSeed(byte[] seed) { /* NOOP */ }
     };
     
-    private NotSecurePsuedoRandom() {
+    private NotSecurePseudoRandom() {
       super(NOT_SECURE_SPI, null) ;
     }
     

Reply via email to
diff --git 
a/solr/core/src/test/org/apache/solr/cloud/TestCloudPseudoReturnFields.java 
b/solr/core/src/test/org/apache/solr/cloud/TestCloudPseudoReturnFields.java
index 7e4a67a..aa1a6e5 100644
--- a/solr/core/src/test/org/apache/solr/cloud/TestCloudPseudoReturnFields.java
+++ b/solr/core/src/test/org/apache/solr/cloud/TestCloudPseudoReturnFields.java
@@ -76,7 +76,7 @@ public class TestCloudPseudoReturnFields extends 
SolrCloudTestCase {
     
     Map<String, String> collectionProperties = new HashMap<>();
     collectionProperties.put("config", "solrconfig-tlog.xml");
-    collectionProperties.put("schema", "schema-psuedo-fields.xml");
+    collectionProperties.put("schema", "schema-pseudo-fields.xml");
     CollectionAdminRequest.createCollection(COLLECTION_NAME, configName, 
numShards, repFactor)
         .setProperties(collectionProperties)
         .process(cluster.getSolrClient());
@@ -126,7 +126,7 @@ public class TestCloudPseudoReturnFields extends 
SolrCloudTestCase {
     // a multi valued field (the field value is copied first, then
     // if the type lookup is done again later, we get the wrong thing). 
SOLR-4036
 
     // score as psuedo field - precondition checks
     for (String name : new String[] {"score", "val_ss"}) {
       try {
         FieldResponse frsp = new Field(name, params("includeDynamic","true",
@@ -147,7 +147,7 @@ public class TestCloudPseudoReturnFields extends 
SolrCloudTestCase {
 
     SolrDocument doc = null;
     
     // score as psuedo field
     doc = assertSearchOneDoc(params("q","*:*", "fq", "id:42", 
"fl","id,score,val_ss,val2_ss"));
     assertEquals("42", doc.getFieldValue("id"));
     assertEquals(1.0F, doc.getFieldValue("score"));
@@ -156,7 +156,7 @@ public class TestCloudPseudoReturnFields extends 
SolrCloudTestCase {
     // TODO: update this test & TestPseudoReturnFields to index docs using a 
(multivalued) "val_ss" instead of "ssto"
     //
     // that way we can first sanity check a single value in a multivalued 
field is returned correctly
-    // as a "List" of one element, *AND* then we could be testing that a 
(single valued) psuedo-field correctly
+    // as a "List" of one element, *AND* then we could be testing that a 
(single valued) pseudo-field correctly
     // overrides that actual (real) value in a multivalued field (ie: not 
@@ -126,7 +126,7 @@ public class TestCloudPseudoReturnFields extends 
SOLR-4036
 
-    // score as psuedo field - precondition checks
+    // score as pseudo field - precondition checks
     for (String name : new String[] {"score", "val_ss"}) {
       try {
@@ -147,7 +147,7 @@ public class TestCloudPseudoReturnFields extends 
     SolrDocument doc = null;
     
-    // score as psuedo field
+    // score as pseudo field
     doc = assertSearchOneDoc(params("q","*:*", "fq", "id:42", 
"fl","id,score,val_ss,val2_ss"));
returning a an List)
     //
     // (NOTE: not doing this yet due to how it will impact most other tests, 
many of which are currently
diff --git 
a/solr/core/src/test/org/apache/solr/search/TestPseudoReturnFields.java 
b/solr/core/src/test/org/apache/solr/search/TestPseudoReturnFields.java
index e56f265..b905640 100644
--- a/solr/core/src/test/org/apache/solr/search/TestPseudoReturnFields.java
+++ b/solr/core/src/test/org/apache/solr/search/TestPseudoReturnFields.java
@@ -51,7 +51,7 @@ public class TestPseudoReturnFields extends SolrTestCaseJ4 {
 
   @BeforeClass
   public static void beforeTests() throws Exception {
-    initCore("solrconfig-tlog.xml","schema-psuedo-fields.xml");
+    initCore("solrconfig-tlog.xml","schema-pseudo-fields.xml");
 
     assertU(adoc("id", "42", "val_i", "1", "ssto", "X", "subject", "aaa"));
     assertU(adoc("id", "43", "val_i", "9", "ssto", "X", "subject", "bbb"));
@@ -76,7 +76,7 @@ public class TestPseudoReturnFields extends SolrTestCaseJ4 {
     // a multi valued field (the field value is copied first, then
     // if the type lookup is done again later, we get the wrong thing). 
SOLR-4036
 
     // score as psuedo field - precondition checks
     for (String name : new String[] {"score", "val_ss"}) {
       SchemaField sf = h.getCore().getLatestSchema().getFieldOrNull(name);
       assertNotNull("Test depends on a (dynamic) field mtching '"+name+
@@ -85,7 +85,7 @@ public class TestPseudoReturnFields extends SolrTestCaseJ4 {
                  "', schema was changed out from under us!", sf.multiValued());
     }
 
     // score as psuedo field
     assertJQ(req("q","*:*", "fq", "id:42", "fl","id,score")
              ,"/response/docs==[{'id':'42','score':1.0}]");
     
@@ -76,7 +76,7 @@ public class TestPseudoReturnFields extends SolrTestCaseJ4 {
SOLR-4036
 
-    // score as psuedo field - precondition checks
+    // score as pseudo field - precondition checks
     for (String name : new String[] {"score", "val_ss"}) {
       SchemaField sf = h.getCore().getLatestSchema().getFieldOrNull(name);
@@ -85,7 +85,7 @@ public class TestPseudoReturnFields extends SolrTestCaseJ4 {
     }
 
-    // score as psuedo field
+    // score as pseudo field
     assertJQ(req("q","*:*", "fq", "id:42", "fl","id,score")
              ,"/response/docs==[{'id':'42','score':1.0}]");
diff --git a/solr/solr-ref-guide/tools/CheckLinksAndAnchors.java 
b/solr/solr-ref-guide/tools/CheckLinksAndAnchors.java
index 1ef447c..d979b40 100644
--- a/solr/solr-ref-guide/tools/CheckLinksAndAnchors.java
+++ b/solr/solr-ref-guide/tools/CheckLinksAndAnchors.java
@@ -84,7 +84,7 @@ import org.jsoup.select.Elements;
  *      <li>Jekyll Mode:
  *        <ul>
  *          <li>Requires all html pages have a "content" div; ignores all DOM 
Nodes that are
- *              <em>not</em> decendents of this div (to exclude redundent 
template based header, footer,
+ *              <em>not</em> descendants of this div (to exclude redundant 
template based header, footer,
  *              &amp; sidebar links)
  *          </li>
  *          <li>Expects that the <code>&lt;body/&gt;</code> tag will have an 
<code>id</code> matching
@@ -318,15 +318,15 @@ public class CheckLinksAndAnchors { // TODO: rename this 
class now that it does
     int problems = 0;
 
     for (Element tab : mainContent.select(".dynamic-tabs")) {
       // must be at least two tab-pane decendents of each dynamic-tabs
       final Elements panes = tab.select(".tab-pane");
       final int numPanes = panes.size();
       if (numPanes < 2) {
-        System.err.println(file + " contains a 'dynamic-tabs' with "+ 
numPanes+" 'tab-pane' decendents -- must be at least 2");
+        System.err.println(file + " contains a 'dynamic-tabs' with "+ 
numPanes+" 'tab-pane' descendants -- must be at least 2");
         problems++;
       }
 
-      // must not have any decendents of a dynamic-tabs that are not part of 
tab-pane
+      // must not have any descendants of a dynamic-tabs that are not part of 
tab-pane
       //
       // this is kind of tricky, because asciidoctor creates wrapper divs 
around the tab-panes
       // so we can't make assumptions about direct children
@@ -335,11 +335,11 @@ public class CheckLinksAndAnchors { // TODO: rename this 
class now that it does
       for (Element pane : panes) {
         elementsToIgnore.addAll(pane.select("*"));
       }
-      final Elements nonPaneDecendents = tab.select("*");
-      nonPaneDecendents.removeAll(elementsToIgnore);
-      if (0 != nonPaneDecendents.size()) {
+      final Elements nonPaneDescendants = tab.select("*");
+      nonPaneDescendants.removeAll(elementsToIgnore);
+      if (0 != nonPaneDescendants.size()) {
         System.err.println(file + " contains a 'dynamic-tabs' with content 
outside of a 'tab-pane': " +
-                           shortStr(nonPaneDecendents.text()));
+                           shortStr(nonPaneDescendants.text()));
         problems++;
       }
     }
@@ -363,16 +363,16 @@ public class CheckLinksAndAnchors { // TODO: rename this 
class now that it does
         problems++;
       }
 
-      // every tab-pane must be a decendent of a dynamic-tabs
+      // every tab-pane must be a descendant of a dynamic-tabs
       if (! validPanes.contains(pane)) {
-        System.err.println(file + " contains " + debug + " that is not a 
decendent of a 'dynamic-tabs'");
+        System.err.println(file + " contains " + debug + " that is not a 
dependent of a 'dynamic-tabs'");
         problems++;
       }
 
       // every tab-pane must have exactly 1 tab-label which is <strong>
       Elements labels = pane.select(".tab-label");
       if (1 != labels.size()) {
-        System.err.println(file + " contains " + debug + " with " + 
labels.size() + " 'tab-label' decendents -- must be exactly 1");
+        System.err.println(file + " contains " + debug + " with " + 
labels.size() + " 'tab-label' descendants -- must be exactly 1");
         problems++;
       } else {
@@ -318,15 +318,15 @@ public class CheckLinksAndAnchors { // TODO: rename this 
 
     for (Element tab : mainContent.select(".dynamic-tabs")) {
-      // must be at least two tab-pane decendents of each dynamic-tabs
+      // must be at least two tab-pane descendants of each dynamic-tabs
       final Elements panes = tab.select(".tab-pane");
       final int numPanes = panes.size();
         Element label = labels.first();
diff --git 
a/solr/solrj/src/java/org/apache/solr/client/solrj/io/stream/RandomStream.java 
b/solr/solrj/src/java/org/apache/solr/client/solrj/io/stream/RandomStream.java
index ba2a799..09a402b 100644
--- 
a/solr/solrj/src/java/org/apache/solr/client/solrj/io/stream/RandomStream.java
+++ 
b/solr/solrj/src/java/org/apache/solr/client/solrj/io/stream/RandomStream.java
@@ -53,7 +53,7 @@ import org.apache.solr.common.params.ModifiableSolrParams;
 import static org.apache.solr.common.params.CommonParams.SORT;
 
 /**
- *  The RandomStream emits a stream of psuedo random Tuples that match the 
query parameters. Sample expression syntax:
+ *  The RandomStream emits a stream of pseudo random Tuples that match the 
query parameters. Sample expression syntax:
  *  random(collection, q="Hello word", rows="50", fl="title, body")
  * @since 6.1.0
  **/
diff --git 
a/solr/solrj/src/test/org/apache/solr/client/ref_guide_examples/IndexingNestedDocuments.java
 
b/solr/solrj/src/test/org/apache/solr/client/ref_guide_examples/IndexingNestedDocuments.java
index c853c7e..7d10b2a 100644
--- 
a/solr/solrj/src/test/org/apache/solr/client/ref_guide_examples/IndexingNestedDocuments.java
+++ 
b/solr/solrj/src/test/org/apache/solr/client/ref_guide_examples/IndexingNestedDocuments.java
@@ -150,7 +150,7 @@ public class IndexingNestedDocuments extends 
SolrCloudTestCase {
   }
   
   /**
-   * Demo of using <code>NestPath</code> related psuedo-fields when indexing 
hierarchical documents.
+   * Demo of using <code>NestPath</code> related pseudo-fields when indexing 
hierarchical documents.
    * This test code is used as an 'include' from the ref-guide
    */
   public void testIndexingUsingNestPath() throws Exception {
diff --git 
a/solr/solrj/src/test/org/apache/solr/client/solrj/SolrExampleTests.java 
b/solr/solrj/src/test/org/apache/solr/client/solrj/SolrExampleTests.java
index f106cbe..7a69eda 100644
--- a/solr/solrj/src/test/org/apache/solr/client/solrj/SolrExampleTests.java
+++ b/solr/solrj/src/test/org/apache/solr/client/solrj/SolrExampleTests.java
@@ -1963,8 +1963,8 @@ abstract public class SolrExampleTests extends 
SolrExampleTestsBase
       if (outDoc.hasChildDocuments()) {
         for (SolrDocument kid : outDoc.getChildDocuments()) {
           String kidId = (String)kid.getFieldValue("id");
-          SolrInputDocument origChild = findDecendent(origDoc, kidId);
-          assertNotNull(docId + " doesn't have decendent " + kidId,
+          SolrInputDocument origChild = findDescendant(origDoc, kidId);
+          assertNotNull(docId + " doesn't have descendant " + kidId,
                         origChild);
         }
       }
@@ -2004,8 +2004,8 @@ abstract public class SolrExampleTests extends 
SolrExampleTestsBase
             String kidId = (String)kid.getFieldValue("id");
             assertEquals("kid is the wrong level",
                          kidLevel, (int)kid.getFieldValue("level_i"));
-            SolrInputDocument origChild = findDecendent(origDoc, kidId);
-            assertNotNull(docId + " doesn't have decendent " + kidId,
+            SolrInputDocument origChild = findDescendant(origDoc, kidId);
+            assertNotNull(docId + " doesn't have descendant " + kidId,
                           origChild);
           }
         }
@@ -2031,8 +2031,8 @@ abstract public class SolrExampleTests extends 
SolrExampleTestsBase
         if (outDoc.hasChildDocuments()) {
           for (SolrDocument kid : outDoc.getChildDocuments()) {
             String kidId = (String)kid.getFieldValue("id");
-            SolrInputDocument origChild = findDecendent(origDoc, kidId);
-            assertNotNull(docId + " doesn't have decendent " + kidId,
+            SolrInputDocument origChild = findDescendant(origDoc, kidId);
+            assertNotNull(docId + " doesn't have descendant " + kidId,
                           origChild);
           }
           // the total number of kids should be our direct kids and our 
grandkids
@@ -2086,8 +2086,8 @@ abstract public class SolrExampleTests extends 
SolrExampleTestsBase
                        kidLevel <= kidLevelMax);
             assertTrue("kid level to low: " + kidLevelMin + ">" + kidLevel,
                        kidLevelMin <= kidLevel);
-            SolrInputDocument origChild = findDecendent(origDoc, kidId);
-            assertNotNull(docId + " doesn't have decendent " + kidId,
+            SolrInputDocument origChild = findDescendant(origDoc, kidId);
+            assertNotNull(docId + " doesn't have descendant " + kidId,
                           origChild);
           }
         }
@@ -2241,10 +2241,10 @@ abstract public class SolrExampleTests extends 
SolrExampleTestsBase
   }
 
   /** 
    * Depth first search of a SolrInputDocument looking for a decendent by id, 
    * returns null if it's not a decendent 
    */
-  private SolrInputDocument findDecendent(SolrInputDocument parent, String 
childId) {
+  private SolrInputDocument findDescendant(SolrInputDocument parent, String 
childId) {
     if (childId.equals(parent.getFieldValue("id"))) {
       return parent;
     }
@@ -2252,7 +2252,7 @@ abstract public class SolrExampleTests extends 
SolrExampleTestsBase
       return null;
     }
     for (SolrInputDocument kid : parent.getChildDocuments()) {
-      SolrInputDocument result = findDecendent(kid, childId);
+      SolrInputDocument result = findDescendant(kid, childId);
       if (null != result) {
         return result;
       }
@@ -2268,7 +2268,7 @@ abstract public class SolrExampleTests extends 
SolrExampleTestsBase
 
   /**
    * recursive method for generating a document, which may also have child 
documents;
-   * adds all documents constructed (including decendents) to allDocs via 
their id 
+   * adds all documents constructed (including descendants) to allDocs via 
their id
    */
   private SolrInputDocument genNestedDocuments(Map<String,SolrInputDocument> 
@@ -2241,10 +2241,10 @@ abstract public class SolrExampleTests extends 
 
   /** 
-   * Depth first search of a SolrInputDocument looking for a decendent by id, 
-   * returns null if it's not a decendent 
+   * Depth first search of a SolrInputDocument looking for a descendant by id,
+   * returns null if it's not a descendant
    */
allDocs, 
                                                int thisLevel,